@@ -5,8 +5,14 @@ import websocket
 
 
 class WebsocketFrameReader(object):
-    def __init__(self, url, access_token_provider: Callable[[], str], verify_ssl: bool = True,
-                 proxy_host: Optional[str] = None, proxy_port: Optional[int] = None):
+    def __init__(
+        self,
+        url,
+        access_token_provider: Callable[[], str],
+        verify_ssl: bool = True,
+        proxy_host: Optional[str] = None,
+        proxy_port: Optional[int] = None,
+    ):
         if not verify_ssl:
             self._ws = websocket.WebSocket(sslopt=dict(cert_reqs=ssl.CERT_NONE))
         else:
@@ -17,10 +23,10 @@ class WebsocketFrameReader(object):
         self._access_token_provider = access_token_provider
 
     def connect(self):
-        kw_args = dict(header=dict(Authorization='Bearer %s' % self._access_token_provider()))
+        kw_args = dict(header=dict(Authorization="Bearer %s" % self._access_token_provider()))
         if self._proxy_host is not None and self._proxy_port is not None:
-            kw_args['http_proxy_host'] = self._proxy_host
-            kw_args['http_proxy_port'] = str(self._proxy_port)
+            kw_args["http_proxy_host"] = self._proxy_host
+            kw_args["http_proxy_port"] = str(self._proxy_port)
         self._ws.connect(self._url, **kw_args)
 
     def close(self):
@@ -38,5 +44,5 @@ class WebsocketFrameReader(object):
         try:
             for frame in self._ws:
                 yield frame
-        except websocket.WebSocketConnectionClosedException as _:
+        except websocket.WebSocketConnectionClosedException:
             pass
